<?php
/**
 * consult functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package consult
 */


define( 'CONSULT_THEMEROOT_URI', get_template_directory_uri() );
define( 'CONSULT_CSS', CONSULT_THEMEROOT_URI . '/assets/css' );
define( 'CONSULT_IMAGES', CONSULT_THEMEROOT_URI . '/assets/images' );
define( 'CONSULT_SCRIPTS', CONSULT_THEMEROOT_URI . '/assets/js' );
define( 'CONSULT_FRAMEWORK', get_template_directory() . '/inc' );
define(	'CONSULT_CUSTOMIZER_DIR', get_template_directory() . '/inc/customizer/');
define(	'CONSULT_SHORTCODE_DIR', get_template_directory() . '/inc/elementor/widgets');
define(	'CONSULT_SHORTCODE_DIR_ASSETS', get_template_directory() . '/inc/elementor/assets');


if ( ! defined( 'CONSULT_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'CONSULT_VERSION', '1.0.0' );
}

if ( ! function_exists( 'consult_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function consult_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on consult, use a find and replace
		 * to change 'consult' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'consult', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		add_theme_support( 'custom-header', array( 'header-text' => false ) );

		/* custom-header */
		$args = array(
    	'width'         => 1920,
    	'height'        => 500,
		);
		add_theme_support( 'custom-header', $args );

		/* Editor style */
		add_editor_style();

		/* Register menu */
		register_nav_menus( array(
			'primary' => esc_html__( 'Main Navigation', 'consult' )
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'consult_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'consult_setup' );


function consult_google_font_url() {
    $font_url = '';
    if ( 'off' !== esc_html__( 'on', 'consult' ) ) {
        $font_url = add_query_arg( 'family', urlencode( 'Lato:400,400i,700|Prata' ), "//fonts.googleapis.com/css" );
    }
    return $font_url;
}


/**
 * Unique ID.
 */

function consult_unique_id( $prefix = '' ) {
  static $id_counter = 0;
  if ( function_exists( 'wp_unique_id' ) ) {
    return wp_unique_id( $prefix );
  }
  return $prefix . (string) ++$id_counter;
}


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function consult_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'consult_content_width', 640 );
}
add_action( 'after_setup_theme', 'consult_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function consult_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'consult' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'consult' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Page Sidebar', 'consult' ),
			'id'            => 'sidebar-2',
			'description'   => esc_html__( 'Add widgets here.', 'consult' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);
}
add_action( 'widgets_init', 'consult_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function consult_scripts() {
	wp_enqueue_style( 'swiper-slider', CONSULT_CSS .'/swiper.css', array(), '1.0.1', 'all' );
	wp_enqueue_style( 'themify-icons', CONSULT_CSS .'/themify-icons.css', array(), '1.0.1', 'all' );
	wp_enqueue_style( 'bootstrap-style', CONSULT_CSS .'/bootstrap.css', array(), '3.3.7', 'all' );
	wp_enqueue_style( 'owl-carousel', CONSULT_CSS .'/owl.carousel.css', array(), '4.4.1', 'all' );
	wp_enqueue_style( 'consult-main-style', CONSULT_CSS .'/style.css', array(), '1.0.1', 'all' );
	wp_enqueue_style( 'consult-style', get_stylesheet_uri(), array(), CONSULT_VERSION );
	wp_style_add_data( 'consult-style', 'rtl', 'replace' );
	wp_enqueue_style( 'consult-default-google-fonts', esc_url( consult_google_font_url() ), array(), '1.0.0', 'all' );

	wp_enqueue_script( 'consult-navigation', CONSULT_SCRIPTS . '/navigation.js', array(), CONSULT_VERSION, true );
	wp_enqueue_script( 'bootstrap', CONSULT_SCRIPTS . '/bootstrap.js', array( 'jquery' ), '3.3.7', true );
	wp_enqueue_script( 'swiper-slider', CONSULT_SCRIPTS . '/swiper.js', array( 'jquery' ), '3.3.7', true );
	wp_enqueue_script( 'owl-carousel', CONSULT_SCRIPTS . '/owl-carousel.js', array( 'jquery' ), '2.0.0', true );
	wp_enqueue_script( 'consult-scripts', CONSULT_SCRIPTS . '/scripts.js',array( 'jquery' ), '1.0.0', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'consult_scripts' );



/**
 * Enqueue a script in the WordPress admin on edit.php.
 *
 * @param int $hook Hook suffix for the current admin page.
 */
function consult_admin_scripts_styles( $hook ) {
    if ( 'index.php' != $hook ) {
        return;
    }
     wp_enqueue_style( 'consult-admin-custom-style', CONSULT_CSS . '/admin-styles.css', true );
}
add_action( 'admin_enqueue_scripts', 'consult_admin_scripts_styles' );


/**
 * Fix skip link focus in IE11.
 *
 * This does not enqueue the script because it is tiny and because it is only for IE11,
 * thus it does not warrant having an entire dedicated blocking script being loaded.
 *
 * @link https://git.io/vWdr2
 */
function consult_skip_link_focus_fix() {
	// The following is minified via `terser --compress --mangle -- assets/js/skip-link-focus-fix.js`.
	?>
	<script>
	/(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
	</script>
	<?php
}
add_action( 'wp_print_footer_scripts', 'consult_skip_link_focus_fix' );


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';


/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/* Install Plugins */
require_once( CONSULT_FRAMEWORK . '/theme-options/plugins/activation.php' );

/* Breadcrumbs */
require_once( CONSULT_FRAMEWORK . '/theme-options/plugins/breadcrumb-trail.php' );

/* Metabox */
require_once( CONSULT_FRAMEWORK . '/theme-options/lib/custom-metabox.php' );

/* Customizer */
require_once( CONSULT_FRAMEWORK . '/theme-options/customizer/kirki-installer.php' );
require_once( CONSULT_FRAMEWORK . '/theme-options/customizer/customizer.php' );

/* Custom Style */
require_once( CONSULT_FRAMEWORK . '/theme-options/customizer/custom-style.php' );

//Elementor
require_once( CONSULT_FRAMEWORK . '/elementor/elementor.php' );
