<?php
/*
 * Elementor Consult Feature Widget
 * Author & Copyright: helloexpert
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Consult_Feature extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'hx-consult_feature';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Feature', 'consult' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-file-signature';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['consult-elements'];
	}

	/**
	 * Retrieve the list of scripts the Consult Feature widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['hx-consult_feature'];
	}
	
	/**
	 * Register Consult Feature widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_feature',
			[
				'label' => esc_html__( 'Feature Options', 'consult' ),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'feature_icon',
			[
				'label' => esc_html__( 'Icon', 'consult' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fi flaticon-money-bag',
					'library' => 'solid',
				],
			]
		);
		$repeater->add_control(
			'feature_title',
			[
				'label' => esc_html__( 'Title Text', 'consult' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'consult' ),
				'placeholder' => esc_html__( 'Type title text here', 'consult' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'feature_content',
			[
				'label' => esc_html__( 'Content', 'consult' ),
				'default' => esc_html__( 'your content text', 'consult' ),
				'placeholder' => esc_html__( 'Type your content here', 'consult' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'feature_link',
			[
				'label' => esc_html__( 'link', 'consult' ),
				'default' => esc_html__( '#', 'consult' ),
				'placeholder' => esc_html__( 'Type your link here', 'consult' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		$this->add_control(
			'featureItems_groups',
			[
				'label' => esc_html__( 'Feature Icons', 'consult' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'feature_title' => esc_html__( 'Feature', 'consult' ),
					],
					
				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ feature_title }}}',
			]
		);
		$this->end_controls_section();// end: Section
		
		// Feature
		$this->start_controls_section(
			'feature_section_style',
			[
				'label' => esc_html__( 'feature', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'feature_section_color',
			[
				'label' => esc_html__( 'Background Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-section .features-grid .grid' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();// end: Section

		//Feature Icons

		$this->start_controls_section(
			'section_icon_style',
			[
				'label' => esc_html__( 'Icon', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'consult_icon_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .feature-section .grid .fi:before, .feature-section .grid i',
			]
		);
		$this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-section .grid .fi:before, .feature-section .grid i' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section
		
		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'consult_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .feature-section .grid h3, .feature-section .grid h3 a',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-section .grid h3, .feature-section .grid h3 a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'consult' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .feature-section .grid h3, .feature-section .grid h3 a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

	// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'section_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .feature-section .grid p',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-section .grid p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		
	}

	/**
	 * Render Feature widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$featureItems_groups = !empty( $settings['featureItems_groups'] ) ? $settings['featureItems_groups'] : [];

		// Turn output buffer on
		ob_start(); ?>

		<div class="feature-section">
		    <div class="features-grid clearfix">
		       <?php 	// Group Param Output
							if( is_array( $featureItems_groups ) && !empty( $featureItems_groups ) ){
							foreach ( $featureItems_groups as $each_item ) { 

							$feature_title = !empty( $each_item['feature_title'] ) ? $each_item['feature_title'] : '';
							$feature_content = !empty( $each_item['feature_content'] ) ? $each_item['feature_content'] : '';
							$feature_link = !empty( $each_item['feature_link'] ) ? $each_item['feature_link'] : '';

							$feature_icon = !empty( $each_item['feature_icon']['value'] ) ? $each_item['feature_icon']['value'] : '';
							$feature_svg_url = !empty( $each_item['feature_icon']['value']['url'] ) ? $each_item['feature_icon']['value']['url'] : '';
							$svg_alt = get_post_meta( $feature_svg_url , '_wp_attachment_image_alt', true);
							

							if ( $feature_link ) {
					      $link_o = '<a href="'. $feature_link .'">';
					      $link_c = '</a>';
					    } else {
					      $link_o = '';
					      $link_c = '';
					    }

					    if( $feature_link ) { echo $link_o; }
						?>

		        <div class="grid">
		            <div class="icon">
		            		<?php if ( $feature_svg_url ) { 
		            			 echo '<img src="'.esc_url( $feature_svg_url ).'" alt="'.esc_url( $svg_alt ).'">';
		            		} else {
		            			echo '<i class="'.esc_attr( $feature_icon ).'"></i>';
		            		}?>
		            </div>
		            <?php 
		            	if( $feature_title ) { echo '<h3>'.esc_html( $feature_title ).'</h3>'; }
		            	if( $feature_content ) { echo '<p>'.esc_html( $feature_content ).'</p>'; }
		             ?>
		        </div>
					<?php 
					if( $feature_link ) { echo $link_c; }
					}
					} ?>
		    </div>
		</div> 

		<?php // Return outbut buffer
			echo ob_get_clean();	
		}
	
}