<?php
/*
 * Elementor Consult Team Widget
 * Author & Copyright: helloexpert
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Consult_Team extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'hx-consult_team';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Team', 'consult' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-users';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['consult-elements'];
	}

	/**
	 * Retrieve the list of scripts the Consult Team widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['hx-consult_team'];
	}
	
	/**
	 * Register Consult Team widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_team',
			[
				'label' => esc_html__( 'Team Options', 'consult' ),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'team_title',
			[
				'label' => esc_html__( 'Title Text', 'consult' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'consult' ),
				'placeholder' => esc_html__( 'Type title text here', 'consult' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'team_subtitle',
			[
				'label' => esc_html__( 'Sub Title Text', 'consult' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Sub Title Text', 'consult' ),
				'placeholder' => esc_html__( 'Type sub title text here', 'consult' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'bg_image',
			[
				'label' => esc_html__( 'Team Image', 'consult' ),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__( 'Set your image.', 'consult'),
			]
		);
		$this->add_control(
			'teamItems_groups',
			[
				'label' => esc_html__( 'Team Items', 'consult' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'team_title' => esc_html__( 'Team', 'consult' ),
					],
					
				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ team_title }}}',
			]
		);

		$this->end_controls_section();// end: Section
		

		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'consult_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .team-section .team-grids h3',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-section .team-grids h3' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'consult' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .team-section .team-grids h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Sub Title
		$this->start_controls_section(
			'section_subtitle_style',
			[
				'label' => esc_html__( 'Sub Title', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'consult_subtitle_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .team-section .team-grids h3 + p',
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-section .team-grids h3 + p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'subtitle_padding',
			[
				'label' => esc_html__( 'Title Padding', 'consult' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .team-section .team-grids h3 + p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		
	}

	/**
	 * Render Team widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$teamItems_groups = !empty( $settings['teamItems_groups'] ) ? $settings['teamItems_groups'] : [];

		// Turn output buffer on
		ob_start();
		?>
		<div class="team-section">
   	 	<div class="team-grids">
			<?php 	// Group Param Output
				if( is_array( $teamItems_groups ) && !empty( $teamItems_groups ) ){
				foreach ( $teamItems_groups as $each_items) { 

				$team_title = !empty( $each_items['team_title'] ) ? $each_items['team_title'] : '';
				$team_subtitle = !empty( $each_items['team_subtitle'] ) ? $each_items['team_subtitle'] : '';
				$bg_image = !empty( $each_items['bg_image']['id'] ) ? $each_items['bg_image']['id'] : '';

				$image_url = wp_get_attachment_url( $each_items['bg_image']['id'] );
				$image_alt = get_post_meta( $each_items['bg_image']['id'], '_wp_attachment_image_alt', true);

				?>
        <div class="grid">
            <div class="img-holder">
             <?php 
              	if( $image_url ) { echo '<img src="'.esc_url( $image_url ).'" alt="'.esc_attr( $image_alt ).'">'; }
              ?>
            </div>
            <div class="details">
	              <?php 
	              	if( $team_title ) { echo '<h3>'.esc_html( $team_title ).'</h3>'; } 
	              	if( $team_subtitle ) { echo '<p>'.esc_html( $team_subtitle ).'</p>'; }
	              ?>
            </div>
        </div>
				<?php }
				} ?>
		  </div>
		</div>
		<?php
			// Return outbut buffer
			echo ob_get_clean();	
		}
	
}