<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package consult
 */
get_header();

$consult_blog_layout = get_theme_mod( 'consult_blog_layout_setting', '' );

// Sidebar Position
if ( $consult_blog_layout === 'hide-sidebar' ) {
	$blog_layout_class = 'col col-md-10 col-md-offset-1';
	$blog_sidebar_class = '';
	$blog_consult_sidebar_class = 'hide-sidebar';
} elseif ( $consult_blog_layout === 'left-sidebar' ) {
	$blog_layout_class = 'col col-md-8 col-md-push-4';
	$blog_sidebar_class = 'col col-md-4 col-md-pull-8';
	$blog_consult_sidebar_class = 'left-sidebar';
} elseif( !is_active_sidebar( 'sidebar-1' ) ) {
	$blog_layout_class = 'col col-md-12';
	$blog_sidebar_class = '';
	$blog_consult_sidebar_class = 'not-active-sidebar';
}	else {
	$blog_layout_class = 'col col-md-8';
	$blog_sidebar_class = 'col col-md-4';
	$blog_consult_sidebar_class = 'right-sidebar';
}

?>
<div class="blog-pg-section section-padding" id="site-content">
	<div class="container">
		<div class="row">
				<div class="<?php echo esc_attr( $blog_layout_class ); ?>">
					<main id="primary" class="site-main">
						<?php
						if ( have_posts() ) :

							if ( is_home() && ! is_front_page() ) :
								?>
								<header>
									<h1 class="page-title screen-reader-text"><?php single_post_title(); ?></h1>
								</header>
								<?php
							endif;

							/* Start the Loop */
							while ( have_posts() ) :
								the_post();

								/*
								 * Include the Post-Type-specific template for the content.
								 * If you want to override this in a child theme, then include a file
								 * called content-___.php (where ___ is the Post Type name) and that will be used instead.
								 */
								get_template_part( 'theme-layouts/post/content', 'search');

							endwhile;

							the_posts_navigation();

						else :

							get_template_part( 'theme-layouts/post/content', 'none' );

						endif;
						?>
					</main><!-- #main -->
				</div>
				<?php
					if ( $consult_blog_layout !== 'hide-sidebar' && is_active_sidebar( 'sidebar-1' ) ) {
					 ?>
						<div class="<?php if ( isset( $blog_sidebar_class ) ) { echo esc_attr( $blog_sidebar_class ); } ?>">
							<?php get_sidebar(); ?>
						</div>
					<?php 
					} 
				?>
		</div>
	</div>
</div>
<?php
get_footer();
